==> spip_4.2.9+dfsg.orig.tar.xz: ecrire/lang/public_bg.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=bg
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Начало', # MODIF
	'articles' => 'Статии',
	'articles_auteur' => 'Статии на автора',
	'articles_populaires' => 'Най-популярните статии',
	'articles_rubrique' => 'Статии от рубриката',
	'aucun_article' => 'На този адрес не бе намерена статия',
	'aucun_auteur' => 'На този адрес не бе намерен автор',
	'aucun_site' => 'На този адрес не бе намерен сайт',
	'aucune_breve' => 'На този адрес не бяха намерени новини',
	'aucune_rubrique' => 'На този адрес не бе намерена рубрика',
	'autres_breves' => 'Други новини',
	'autres_groupes_mots_clefs' => 'Други групи от ключови думи',
	'autres_sites' => 'Други сайтове',

	// B
	'bonjour' => 'Добър ден',

	// C
	'commenter_site' => 'Коментар на сайта',

	// D
	'date' => 'Дата',
	'dernier_ajout' => 'Най-новото допълнение',
	'dernieres_breves' => 'Последните новини',
	'derniers_articles' => 'Най-новите статии',
	'derniers_commentaires' => 'Най-новите коментари',
	'derniers_messages_forum' => 'Най-новите съобщения, публикувани на форума',

	// E
	'edition_mode_texte' => 'текстов вид',
	'en_reponse' => 'В отговор на:',
	'en_resume' => 'Резюме',
	'envoyer_message' => 'Изпращане на съобщение',
	'espace_prive' => 'Лична зона',

	// H
	'hierarchie_site' => 'Структура на сайта',

	// J
	'jours' => 'дни',

	// M
	'meme_auteur' => 'От същия автор',
	'meme_rubrique' => 'В същата рубрика',
	'memes_auteurs' => 'От същите автори',
	'message' => 'Съобщение',
	'messages_forum' => 'Съобщения в форума', # MODIF
	'messages_recents' => 'Най-новите съобщения от форума',
	'mots_clefs' => 'Ключови думи',
	'mots_clefs_meme_groupe' => 'Ключови думи от същата група',

	// N
	'navigation' => 'Навигация',
	'nom' => 'Име',
	'nouveautes' => 'Какво ново?',
	'nouveautes_web' => 'Какво ново в мрежата?',
	'nouveaux_articles' => 'Нови статии',
	'nouvelles_breves' => 'Последни новини',

	// P
	'page_precedente' => 'предишна страница',
	'page_suivante' => 'следваща страница',
	'par_auteur' => 'от',
	'participer_site' => 'За да вземете активно участие в работата на сайта и да пишете свои собствени статии, е нужно първо да се регистрирате тук. При регистрация ще получите незабавно съобщение на електронния си адрес с код за достъп до личната зона на сайта.',
	'plan_site' => 'Карта на сайта',
	'popularite' => 'Популярност',
	'poster_message' => 'Изпращане на съобщение',
	'proposer_site' => 'Предложете сайт, който да бъде добавен към рубриката:',

	// R
	'repondre_article' => 'Отговор на статията',
	'repondre_breve' => 'Отговор на новината',
	'resultats_recherche' => 'Резултати от търсенето',
	'retour_debut_forums' => 'Обратно в началото на форумите',
	'rubrique' => 'Рубрика',
	'rubriques' => 'Рубрики',

	// S
	'signatures_petition' => 'Записи',
	'site_realise_avec_spip' => 'Сайт под СПИП',
	'sites_web' => 'Интернет сайтове',
	'sous_rubriques' => 'Подрубрики',
	'suite' => 'продължава',
	'sur_web' => 'В мрежата',
	'syndiquer_rubrique' => 'Обединяване на тази рубрика',
	'syndiquer_site' => 'Обединяване на целия сайт',

	// T
	'texte_lettre_information' => 'Това е бюлетина на сайта',
	'texte_lettre_information_2' => 'Писмото резюмира статиите и новините публикувани от последните', # MODIF

	// V
	'ver_imprimer' => 'Версия за отпечатване',
	'voir_en_ligne' => 'Виж как ще изглежда',
	'voir_squelette' => 'Изтеглете шаблона на тази страница'
);

==> spip_4.4.6+dfsg.orig.tar.xz: ecrire/lang/public_bg.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=bg
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Начало', # MODIF
	'articles' => 'Статии',
	'articles_auteur' => 'Статии на автора',
	'articles_populaires' => 'Най-популярните статии',
	'articles_rubrique' => 'Статии от рубриката',
	'aucun_article' => 'На този адрес не бе намерена статия',
	'aucun_auteur' => 'На този адрес не бе намерен автор',
	'aucun_site' => 'На този адрес не бе намерен сайт',
	'aucune_breve' => 'На този адрес не бяха намерени новини',
	'aucune_rubrique' => 'На този адрес не бе намерена рубрика',
	'autres_breves' => 'Други новини',
	'autres_groupes_mots_clefs' => 'Други групи от ключови думи',
	'autres_sites' => 'Други сайтове',

	// B
	'bonjour' => 'Добър ден',

	// C
	'commenter_site' => 'Коментар на сайта',

	// D
	'date' => 'Дата',
	'dernier_ajout' => 'Най-новото допълнение',
	'dernieres_breves' => 'Последните новини',
	'derniers_articles' => 'Най-новите статии',
	'derniers_commentaires' => 'Най-новите коментари',
	'derniers_messages_forum' => 'Най-новите съобщения, публикувани на форума',

	// E
	'edition_mode_texte' => 'текстов вид',
	'en_reponse' => 'В отговор на:',
	'en_resume' => 'Резюме',
	'envoyer_message' => 'Изпращане на съобщение',
	'espace_prive' => 'Лична зона',

	// H
	'hierarchie_site' => 'Структура на сайта',

	// J
	'jours' => 'дни',

	// M
	'meme_auteur' => 'От същия автор',
	'meme_rubrique' => 'В същата рубрика',
	'memes_auteurs' => 'От същите автори',
	'message' => 'Съобщение',
	'messages_forum' => 'Съобщения в форума', # MODIF
	'messages_recents' => 'Най-новите съобщения от форума',
	'mots_clefs' => 'Ключови думи',
	'mots_clefs_meme_groupe' => 'Ключови думи от същата група',

	// N
	'navigation' => 'Навигация',
	'nom' => 'Име',
	'nouveautes' => 'Какво ново?',
	'nouveautes_web' => 'Какво ново в мрежата?',
	'nouveaux_articles' => 'Нови статии',
	'nouvelles_breves' => 'Последни новини',

	// P
	'page_precedente' => 'предишна страница',
	'page_suivante' => 'следваща страница',
	'par_auteur' => 'от',
	'participer_site' => 'За да вземете активно участие в работата на сайта и да пишете свои собствени статии, е нужно първо да се регистрирате тук. При регистрация ще получите незабавно съобщение на електронния си адрес с код за достъп до личната зона на сайта.',
	'plan_site' => 'Карта на сайта',
	'popularite' => 'Популярност',
	'poster_message' => 'Изпращане на съобщение',
	'proposer_site' => 'Предложете сайт, който да бъде добавен към рубриката:',

	// R
	'repondre_article' => 'Отговор на статията',
	'repondre_breve' => 'Отговор на новината',
	'resultats_recherche' => 'Резултати от търсенето',
	'retour_debut_forums' => 'Обратно в началото на форумите',
	'rubrique' => 'Рубрика',
	'rubriques' => 'Рубрики',

	// S
	'signatures_petition' => 'Записи',
	'site_realise_avec_spip' => 'Сайт под СПИП',
	'sites_web' => 'Интернет сайтове',
	'sous_rubriques' => 'Подрубрики',
	'suite' => 'продължава',
	'sur_web' => 'В мрежата',
	'syndiquer_rubrique' => 'Обединяване на тази рубрика',
	'syndiquer_site' => 'Обединяване на целия сайт',

	// T
	'texte_lettre_information' => 'Това е бюлетина на сайта',
	'texte_lettre_information_2' => 'Писмото резюмира статиите и новините публикувани от последните', # MODIF

	// V
	'ver_imprimer' => 'Версия за отпечатване',
	'voir_en_ligne' => 'Виж как ще изглежда',
	'voir_squelette' => 'Изтеглете шаблона на тази страница',
];
